"use strict";

var Prism = require(`prismjs`);
var _ = require(`lodash`);

var loadPrismLanguage = require(`./load-prism-language`);

module.exports = function (language, code) {
  var lineNumbersHighlight = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : [];

  // (Try to) load languages on demand.
  if (!Prism.languages[language]) {
    try {
      loadPrismLanguage(language);
    } catch (e) {
      // Language wasn't loaded so let's bail.
      if (language === `none`) {
        return code; // Don't escape if set to none.
      } else {
        return _.escape(code);
      }
    }
  }

  var lang = Prism.languages[language];

  var highlightedCode = Prism.highlight(code, lang);
  if (lineNumbersHighlight.length > 0) {
    var codeSplits = highlightedCode.split(`\n`).map(function (split, i) {
      if (_.includes(lineNumbersHighlight, i + 1)) {
        return {
          highlighted: true,
          code: `<span class="gatsby-highlight-code-line">${split}\n</span>`
        };
      } else {
        return { code: split };
      }
    });

    highlightedCode = ``;
    var lastIdx = codeSplits.length - 1;
    // Don't add back the new line character after highlighted lines
    // as they need to be display: block and full-width.
    codeSplits.forEach(function (split, idx) {
      split.highlighted ? highlightedCode += split.code : highlightedCode += `${split.code}${idx == lastIdx ? `` : `\n`}`;
    });
  }

  return highlightedCode;
};