"use strict";

var visit = require(`unist-util-visit`);

var parseLineNumberRange = require(`./parse-line-number-range`);
var highlightCode = require(`./highlight-code`);

module.exports = function (_ref) {
  var markdownAST = _ref.markdownAST;

  var _ref2 = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {},
      _ref2$classPrefix = _ref2.classPrefix,
      classPrefix = _ref2$classPrefix === undefined ? `language-` : _ref2$classPrefix,
      _ref2$inlineCodeMarke = _ref2.inlineCodeMarker,
      inlineCodeMarker = _ref2$inlineCodeMarke === undefined ? null : _ref2$inlineCodeMarke,
      _ref2$aliases = _ref2.aliases,
      aliases = _ref2$aliases === undefined ? {} : _ref2$aliases;

  var normalizeLanguage = function normalizeLanguage(lang) {
    var lower = lang.toLowerCase();
    return aliases[lower] || lower;
  };

  visit(markdownAST, `code`, function (node) {
    var language = node.lang;

    var _parseLineNumberRange = parseLineNumberRange(language),
        splitLanguage = _parseLineNumberRange.splitLanguage,
        highlightLines = _parseLineNumberRange.highlightLines;

    language = splitLanguage;

    // PrismJS's theme styles are targeting pre[class*="language-"]
    // to apply its styles. We do the same here so that users
    // can apply a PrismJS theme and get the expected, ready-to-use
    // outcome without any additional CSS.
    //
    // @see https://github.com/PrismJS/prism/blob/1d5047df37aacc900f8270b1c6215028f6988eb1/themes/prism.css#L49-L54
    var languageName = `text`;
    if (language) {
      languageName = normalizeLanguage(language);
    }

    // Allow users to specify a custom class prefix to avoid breaking
    // line highlights if Prism is required by any other code.
    // This supports custom user styling without causing Prism to
    // re-process our already-highlighted markup.
    // @see https://github.com/gatsbyjs/gatsby/issues/1486
    var className = `${classPrefix}${languageName}`;

    // Replace the node with the markup we need to make
    // 100% width highlighted code lines work
    node.type = `html`;
    node.value = `<div class="gatsby-highlight" data-language="${languageName}">
      <pre class="${className}"><code class="${className}">${highlightCode(language, node.value, highlightLines)}</code></pre>
      </div>`;
  });

  visit(markdownAST, `inlineCode`, function (node) {
    var languageName = `text`;

    if (inlineCodeMarker) {
      var _node$value$split = node.value.split(`${inlineCodeMarker}`, 2),
          language = _node$value$split[0],
          restOfValue = _node$value$split[1];

      if (language && restOfValue) {
        languageName = normalizeLanguage(language);
        node.value = restOfValue;
      }
    }

    var className = `${classPrefix}${languageName}`;

    node.type = `html`;
    node.value = `<code class="${className}">${highlightCode(languageName, node.value)}</code>`;
  });
};